@@ -35,7 +35,7 @@ try {
     }
     
     // Get all containers for this site
-    $stmt = $db->prepare("SELECT container_id FROM whp.site_containers WHERE site_id = ? AND status = 'active'");
+    $stmt = $db->prepare("SELECT container_id FROM whp.site_containers WHERE site_id = ? AND status = 'running'");
     $stmt->execute([$site_id]);
     $containers = $stmt->fetchAll(PDO::FETCH_COLUMN);
     
