@@ -49,28 +49,19 @@ $server_description = $server_settings['server_description'] ?? 'Web Hosting Pan
     </head>
     <body class="account<?php echo (isset($_SESSION['large_fonts']) && $_SESSION['large_fonts']) ? ' large-fonts' : ''; ?>">
         <!-- Theme Toggle for Login Page -->
-        <div class="login-font-toggle" style="top: 1rem; right: 1rem;">
-            <label class="font-size-toggle-label" for="themeToggle">
-                <span class="font-size-icons">
-                    <i class="fa fa-sun-o"></i>
-                    <i class="fa fa-moon-o"></i>
-                </span>
-                <div class="toggle-switch" title="Toggle light/dark theme">
-                    <input type="checkbox"
-                           id="themeToggle"
-                           <?php
-                           $theme_pref = $_SESSION['theme_preference'] ?? 'auto';
-                           echo ($theme_pref === 'dark') ? '' : 'checked';
-                           ?>
-                           aria-label="Toggle light/dark theme"
-                           role="switch">
-                    <span class="toggle-slider"></span>
-                </div>
-            </label>
+        <div style="position: absolute; top: 1rem; right: 1rem; z-index: 1000;">
+            <button id="themeToggleBtn"
+                    class="btn btn-sm btn-outline-secondary"
+                    data-theme-pref="<?php echo htmlspecialchars($_SESSION['theme_preference'] ?? 'auto'); ?>"
+                    title="Theme: Auto (follows system)"
+                    aria-label="Toggle theme (Auto/Light/Dark)">
+                <i class="fa fa-adjust"></i>
+                <span id="themeLabel" class="ms-1">Auto</span>
+            </button>
         </div>
 
         <!-- Font Size Toggle for Login Page -->
-        <div class="login-font-toggle" style="top: 4.5rem; right: 1rem;">
+        <div class="login-font-toggle" style="top: 4rem; right: 1rem;">
             <label class="font-size-toggle-label" for="fontSizeToggle">
                 <span class="font-size-icons">
                     <span class="font-size-small">A</span>
@@ -164,45 +155,60 @@ $server_description = $server_settings['server_description'] ?? 'Web Hosting Pan
                 });
             }
 
-            // Theme Toggle Functionality
-            const themeToggle = document.getElementById('themeToggle');
-            if (themeToggle) {
+            // Theme Toggle Functionality (3-state: auto/light/dark)
+            const themeToggleBtn = document.getElementById('themeToggleBtn');
+            const themeLabel = document.getElementById('themeLabel');
+
+            if (themeToggleBtn) {
+                // Theme configuration
+                const themeConfig = {
+                    'auto': { icon: 'fa-adjust', label: 'Auto', title: 'Theme: Auto (follows system)', next: 'light' },
+                    'light': { icon: 'fa-sun-o', label: 'Light', title: 'Theme: Light', next: 'dark' },
+                    'dark': { icon: 'fa-moon-o', label: 'Dark', title: 'Theme: Dark', next: 'auto' }
+                };
+
+                let currentPref = themeToggleBtn.getAttribute('data-theme-pref') || 'auto';
+
                 // Function to apply theme
-                function applyTheme(theme) {
+                function applyTheme(themePref) {
                     const html = document.documentElement;
+                    let actualTheme = themePref;
 
                     // Handle auto theme - detect system preference
-                    if (theme === 'auto') {
+                    if (themePref === 'auto') {
                         const prefersDark = window.matchMedia('(prefers-color-scheme: dark)').matches;
-                        theme = prefersDark ? 'dark' : 'light';
+                        actualTheme = prefersDark ? 'dark' : 'light';
                     }
 
                     // Apply theme attribute
-                    html.setAttribute('data-theme', theme);
+                    html.setAttribute('data-theme', actualTheme);
 
-                    // Update toggle state (checked = light, unchecked = dark)
-                    themeToggle.checked = (theme === 'light');
+                    // Update button appearance
+                    const config = themeConfig[themePref];
+                    const iconElement = themeToggleBtn.querySelector('i');
+                    iconElement.className = 'fa ' + config.icon;
+                    themeLabel.textContent = config.label;
+                    themeToggleBtn.title = config.title;
+                    themeToggleBtn.setAttribute('data-theme-pref', themePref);
+                    currentPref = themePref;
                 }
 
                 // Apply initial theme on page load
-                const initialTheme = document.documentElement.getAttribute('data-theme') || 'dark';
-                applyTheme(initialTheme);
+                applyTheme(currentPref);
 
                 // Listen for system theme changes if using auto mode
                 window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', (e) => {
-                    const currentTheme = document.documentElement.getAttribute('data-theme');
-                    if (currentTheme === 'auto') {
+                    if (currentPref === 'auto') {
                         applyTheme('auto');
                     }
                 });
 
-                // Handle toggle change
-                themeToggle.addEventListener('change', function() {
-                    const isLight = this.checked;
-                    const newTheme = isLight ? 'light' : 'dark';
+                // Handle button click - cycle through themes
+                themeToggleBtn.addEventListener('click', function() {
+                    const nextTheme = themeConfig[currentPref].next;
 
                     // Apply theme immediately for smooth transition
-                    document.documentElement.setAttribute('data-theme', newTheme);
+                    applyTheme(nextTheme);
 
                     // Send AJAX request to save preference
                     fetch('api/theme-toggle.php', {
@@ -211,32 +217,25 @@ $server_description = $server_settings['server_description'] ?? 'Web Hosting Pan
                             'Content-Type': 'application/x-www-form-urlencoded',
                             'X-CSRF-Token': '<?php echo $_SESSION['csrf_token'] ?? ''; ?>'
                         },
-                        body: 'action=set&theme=' + newTheme
+                        body: 'action=set&theme=' + encodeURIComponent(nextTheme)
                     })
                     .then(response => response.json())
                     .then(data => {
                         if (data.success) {
-                            // Update aria-checked for screen readers
-                            themeToggle.setAttribute('aria-checked', isLight ? 'true' : 'false');
-
                             // Announce change to screen readers
                             const announcement = document.createElement('div');
                             announcement.setAttribute('role', 'status');
                             announcement.setAttribute('aria-live', 'polite');
                             announcement.className = 'visually-hidden';
-                            announcement.textContent = isLight ? 'Light theme enabled' : 'Dark theme enabled';
+                            announcement.textContent = 'Theme changed to ' + themeConfig[nextTheme].label;
                             document.body.appendChild(announcement);
                             setTimeout(() => announcement.remove(), 1000);
                         } else {
-                            // Revert on error
-                            applyTheme(newTheme === 'light' ? 'dark' : 'light');
                             console.error('Failed to save theme preference:', data.error);
                         }
                     })
                     .catch(error => {
                         console.error('Error toggling theme:', error);
-                        // Revert on error
-                        applyTheme(newTheme === 'light' ? 'dark' : 'light');
                     });
                 });
             }
