@@ -18,36 +18,54 @@ if ($_SERVER['REQUEST_METHOD'] === 'POST') {
     } elseif (isset($_POST['action'])) {
         switch ($_POST['action']) {
             case 'unblock_ip':
-                if (!empty($_POST['ip_address']) && filter_var($_POST['ip_address'], FILTER_VALIDATE_IP)) {
-                    $ip_address = $_POST['ip_address'];
+                $ip_input = trim($_POST['ip_address'] ?? '');
+
+                // Validate IP or CIDR notation
+                $is_valid = false;
+                if (filter_var($ip_input, FILTER_VALIDATE_IP)) {
+                    $is_valid = true;
+                } elseif (strpos($ip_input, '/') !== false) {
+                    list($ip, $mask) = explode('/', $ip_input, 2);
+                    if (filter_var($ip, FILTER_VALIDATE_IP, FILTER_FLAG_IPV4) &&
+                        is_numeric($mask) && $mask >= 0 && $mask <= 32) {
+                        $is_valid = true;
+                    }
+                }
+
+                if ($is_valid && !empty($ip_input)) {
                     $errors = [];
                     $success_count = 0;
-                    
+
                     // Try to unblock from all services and handle errors gracefully
-                    try {
-                        $result1 = $LogMonitor->unblock_ip_from_all_services($ip_address);
-                        if ($result1) {
-                            $success_count++;
+                    // Note: SSH/FTP services only support single IP unblocking, not CIDR
+                    $is_cidr = strpos($ip_input, '/') !== false;
+
+                    if (!$is_cidr) {
+                        try {
+                            $result1 = $LogMonitor->unblock_ip_from_all_services($ip_input);
+                            if ($result1) {
+                                $success_count++;
+                            }
+                        } catch (Exception $e) {
+                            $errors[] = 'Service unblock: Operation failed';
+                            error_log('Service unblock error for IP ' . $ip_input . ': ' . $e->getMessage());
                         }
-                    } catch (Exception $e) {
-                        $errors[] = 'Service unblock: Operation failed';
-                        error_log('Service unblock error for IP ' . $ip_address . ': ' . $e->getMessage());
                     }
-                    
+
                     try {
-                        $result2 = $SecManager->unblock_ip($ip_address);
+                        $result2 = $SecManager->unblock_ip($ip_input);
                         if ($result2) {
                             $success_count++;
                         }
                     } catch (Exception $e) {
                         $errors[] = 'Security manager unblock: Operation failed';
-                        error_log('Security manager unblock error for IP ' . $ip_address . ': ' . $e->getMessage());
+                        error_log('Security manager unblock error for IP ' . $ip_input . ': ' . $e->getMessage());
                     }
-                    
+
                     try {
                         if (class_exists('haproxy_manager')) {
                             $HaproxyManager = new haproxy_manager();
-                            $result3 = $HaproxyManager->unblock_ip($ip_address);
+                            $result3 = $HaproxyManager->unblock_ip($ip_input);
                             if ($result3) {
                                 $success_count++;
                             }
@@ -56,23 +74,25 @@ if ($_SERVER['REQUEST_METHOD'] === 'POST') {
                         }
                     } catch (Exception $e) {
                         $errors[] = 'HAProxy unblock: Operation failed';
-                        error_log('HAProxy unblock error for IP ' . $ip_address . ': ' . $e->getMessage());
+                        error_log('HAProxy unblock error for IP ' . $ip_input . ': ' . $e->getMessage());
                     }
-                    
+
                     if ($success_count > 0) {
+                        $entry_type = $is_cidr ? 'CIDR range' : 'IP address';
                         if (empty($errors)) {
-                            $message = 'IP address unblocked successfully from all services: ' . htmlspecialchars($ip_address);
+                            $message = $entry_type . ' unblocked successfully from all services: ' . htmlspecialchars($ip_input);
                             $message_type = 'success';
                         } else {
-                            $message = 'IP address partially unblocked from ' . $success_count . ' service(s): ' . htmlspecialchars($ip_address) . '. Warnings: ' . implode('; ', $errors);
+                            $message = $entry_type . ' partially unblocked from ' . $success_count . ' service(s): ' . htmlspecialchars($ip_input) . '. Warnings: ' . implode('; ', $errors);
                             $message_type = 'warning';
                         }
                     } else {
-                        $message = 'Failed to unblock IP address from any service: ' . htmlspecialchars($ip_address) . '. Errors: ' . implode('; ', $errors);
+                        $entry_type = $is_cidr ? 'CIDR range' : 'IP address';
+                        $message = 'Failed to unblock ' . $entry_type . ' from any service: ' . htmlspecialchars($ip_input) . '. Errors: ' . implode('; ', $errors);
                         $message_type = 'danger';
                     }
                 } else {
-                    $message = 'Invalid IP address format';
+                    $message = 'Invalid IP address or CIDR format';
                     $message_type = 'danger';
                 }
                 break;
